@@ -6,6 +6,8 @@ require 'base64'
 
 module FeedParser
 
+  VERSION = "0.3"
+
   class UnknownFeedTypeException < RuntimeError
   end
 
@@ -38,7 +40,7 @@ module FeedParser
         # Title
         if (e = doc.root.elements['channel/title'] ||
           doc.root.elements['rss:channel/rss:title']) && e.text
-          @title = e.text.toUTF8(@encoding).rmWhiteSpace!
+          @title = e.text.unescape_html.toUTF8(@encoding).rmWhiteSpace!
         end
         # Link
         if (e = doc.root.elements['channel/link'] ||
@@ -54,7 +56,7 @@ module FeedParser
         if ((e = doc.root.elements['channel/dc:creator']) && e.text) ||
             ((e = doc.root.elements['channel/author'] ||
             doc.root.elements['rss:channel/rss:author']) && e.text)
-          @creator = e.text.toUTF8(@encoding).rmWhiteSpace!
+          @creator = e.text.unescape_html.toUTF8(@encoding).rmWhiteSpace!
         end
         # Items
         if doc.root.elements['channel/item']
@@ -73,7 +75,7 @@ module FeedParser
         @type = "atom"
         # Title
         if (e = doc.root.elements['/feed/title']) && e.text
-          @title = e.text.toUTF8(@encoding).rmWhiteSpace!
+          @title = e.text.unescape_html.toUTF8(@encoding).rmWhiteSpace!
         end
         # Link
         doc.root.each_element('/feed/link') do |e|
@@ -100,7 +102,7 @@ module FeedParser
       end
     end
 
-    def to_s
+    def to_s(localtime = true)
       s  = ''
       s += "Type: #{@type}\n"
       s += "Encoding: #{@encoding}\n"
@@ -109,7 +111,7 @@ module FeedParser
       s += "Description: #{@description}\n"
       s += "Creator: #{@creator}\n"
       s += "\n"
-      @items.each { |i| s += i.to_s }
+      @items.each { |i| s += i.to_s(localtime) }
       s
     end
   end
@@ -119,6 +121,9 @@ module FeedParser
     attr_accessor :title, :link, :content, :date, :creator, :subject,
                   :category, :cacheditem
 
+    # The item's enclosures childs. An array of (url, length, type) triplets.
+    attr_accessor :enclosures
+
     attr_reader :feed
 
     # REXML::Element for this item
@@ -128,6 +133,7 @@ module FeedParser
       @xml = item
       @feed = feed
       @title, @link, @content, @date, @creator, @subject, @category = nil
+      @enclosures = []
       parse(item) if item
     end
 
@@ -135,10 +141,15 @@ module FeedParser
       raise "parse() should be implemented by subclasses!"
     end
 
-    def to_s
+    def to_s(localtime = true)
       s = "--------------------------------\n" +
-        "Title: #{@title}\nLink: #{@link}\n" +
-        "Date: #{@date.to_s}\nCreator: #{@creator}\n" +
+        "Title: #{@title}\nLink: #{@link}\n"
+      if localtime or @date.nil?
+        s += "Date: #{@date.to_s}\n"
+      else
+        s += "Date: #{@date.getutc.to_s}\n"
+      end
+      s += "Creator: #{@creator}\n" +
         "Subject: #{@subject}\nCategory: #{@category}\nContent:\n#{content}\n"
       if defined?(@enclosures) and @enclosures.length > 0
         s2 = "Enclosures:\n"
@@ -153,8 +164,6 @@ module FeedParser
 
   class RSSItem < FeedItem
 
-    # The item's enclosures childs. An array of (url, length, type) triplets.
-    attr_accessor :enclosures
 
     def parse(item)
       # Title. If no title, use the pubDate as fallback.
@@ -162,7 +171,7 @@ module FeedParser
           e.text)  ||
           ((e = item.elements['pubDate'] || item.elements['rss:pubDate']) &&
            e.text)
-        @title = e.text.toUTF8(@feed.encoding).rmWhiteSpace!
+        @title = e.text.unescape_html.toUTF8(@feed.encoding).html2text.rmWhiteSpace!
       end
       # Link
       if ((e = item.elements['link'] || item.elements['rss:link']) && e.text)||
@@ -197,24 +206,23 @@ module FeedParser
       @creator = @feed.creator
       if (e = item.elements['dc:creator'] || item.elements['author'] ||
           item.elements['rss:author']) && e.text
-        @creator = e.text.toUTF8(@feed.encoding).rmWhiteSpace!
+        @creator = e.text.unescape_html.toUTF8(@feed.encoding).rmWhiteSpace!
       end
       # Subject
       if (e = item.elements['dc:subject']) && e.text
-        @subject = e.text.toUTF8(@feed.encoding).rmWhiteSpace!
+        @subject = e.text.unescape_html.toUTF8(@feed.encoding).rmWhiteSpace!
       end
       # Category
       if (e = item.elements['dc:category'] || item.elements['category'] ||
           item.elements['rss:category']) && e.text
-        @category = e.text.toUTF8(@feed.encoding).rmWhiteSpace!
+        @category = e.text.unescape_html.toUTF8(@feed.encoding).rmWhiteSpace!
       end
       # Enclosures
-      @enclosures = []
       item.each_element('enclosure') do |e|
         url = e.attribute('url').value if e.attribute('url')
         length = e.attribute('length').value if e.attribute('length')
         type = e.attribute('type').value if e.attribute('type')
-        @enclosures << [ url, length, type ]
+        @enclosures << [ url, length, type ] if url
       end
     end
   end
@@ -223,17 +231,12 @@ module FeedParser
     def parse(item)
       # Title
       if (e = item.elements['title']) && e.text
-        @title = e.text.toUTF8(@feed.encoding).rmWhiteSpace!
+        @title = e.text.unescape_html.toUTF8(@feed.encoding).html2text.rmWhiteSpace!
       end
       # Link
       item.each_element('link') do |e|
-        if e.attribute('type') and (
-            e.attribute('type').value == 'text/html' or
-            e.attribute('type').value == 'application/xhtml' or
-            e.attribute('type').value == 'application/xhtml+xml')
-          if (h = e.attribute('href')) && h.value
-            @link = h.value
-          end
+        if (h = e.attribute('href')) && h.value
+          @link = h.value
         end
       end
       # Content
@@ -246,7 +249,7 @@ module FeedParser
         end
       end
       # Date
-      if (e = item.elements['issued'] || e = item.elements['created']) && e.text
+      if (e = item.elements['issued'] || e = item.elements['created'] || e = item.elements['published']) && e.text
         begin
           @date = Time::xmlschema(e.text)
         rescue
@@ -264,7 +267,7 @@ module FeedParser
       # Creator
       @creator = @feed.creator
       if (e = item.elements['author/name']) && e.text
-        @creator = e.text.toUTF8(@feed.encoding).rmWhiteSpace!
+        @creator = e.text.unescape_html.toUTF8(@feed.encoding).rmWhiteSpace!
       end
     end
   end
@@ -276,17 +279,19 @@ module FeedParser
     end
     if children.length > 1
       s = ''
-      children.each { |c| s += c.to_s }
-      return s.toUTF8(encoding).rmWhiteSpace!.text2html
+      children.each do |c|
+        s += c.to_s if c.class != REXML::Comment
+      end
+      return s.toUTF8(encoding).rmWhiteSpace!.text2html(feed)
     elsif children.length == 1
       c = children[0]
       if c.class == REXML::Text
-        return e.text.toUTF8(encoding).rmWhiteSpace!.text2html
+        return e.text.toUTF8(encoding).rmWhiteSpace!.text2html(feed)
       else
         if c.class == REXML::CData
-          return c.to_s.toUTF8(encoding).rmWhiteSpace!.text2html
+          return c.to_s.toUTF8(encoding).rmWhiteSpace!.text2html(feed)
         elsif c.text
-          return c.text.toUTF8(encoding).text2html
+          return c.text.toUTF8(encoding).text2html(feed)
         end
       end
     end
