@@ -1,6 +1,9 @@
 #!/usr/bin/ruby -w
 
 $:.unshift File.join(File.dirname(__FILE__), '..', 'lib')
+$:.unshift File.join(File.dirname(__FILE__), '..', 'test')
+$:.unshift File.join(File.dirname(__FILE__), 'lib')
+$:.unshift File.join(File.dirname(__FILE__), 'test')
 
 require 'test/unit'
 require 'feedparser'
@@ -23,7 +26,7 @@ class HTMLOutputTest < Test::Unit::TestCase
       puts "Checking #{f}"
       str = File::read(SRCDIR + '/' + f)
       chan = FeedParser::Feed::new(str)
-      chanstr = chan.to_html
+      chanstr = chan.to_html(false)
       if File::exist?(DSTDIR + '/' + f.gsub(/.xml$/, '.output'))
         output = File::read(DSTDIR + '/' + f.gsub(/.xml$/, '.output'))
         if output != chanstr
