@@ -22,7 +22,7 @@ class ParserTest < Test::Unit::TestCase
       puts "Checking #{f}"
       str = File::read(SRCDIR + '/' + f)
       chan = FeedParser::Feed::new(str)
-      chanstr = chan.to_s
+      chanstr = chan.to_s(false)
       if File::exist?(DSTDIR + '/' + f.gsub(/.xml$/, '.output'))
         output = File::read(DSTDIR + '/' + f.gsub(/.xml$/, '.output'))
         if output != chanstr
